/*****************************************************************************
* File Name: main.c
*
* Version: 1.0
*
* Description:
*   The main C file for the Correlated Double Sampling (CDS) project. 
* 
* Note:
* 	The UART code is only for display and collection of data for comparison. 
* 	It can be deleted and/or replaced as required by user
******************************************************************************
* Copyright (C) 2010, Cypress Semiconductor Corporation.
******************************************************************************
* This software is owned by Cypress Semiconductor Corporation (Cypress) and is
* protected by and subject to worldwide patent protection (United States and
* foreign), United States copyright laws and international treaty provisions.
* Cypress hereby grants to licensee a personal, non-exclusive, non-transferable
* license to copy, use, modify, create derivative works of, and compile the
* Cypress Source Code and derivative works for the sole purpose of creating
* custom software in support of licensee product to be used only in conjunction
* with a Cypress integrated circuit as specified in the applicable agreement.
* Any reproduction, modification, translation, compilation, or representation of
* this software except as specified above is prohibited without the express
* written permission of Cypress.
*
* Disclaimer: CYPRESS MAKES NO WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, WITH
* REGARD TO THIS MATERIAL, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
* WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
* Cypress reserves the right to make changes without further notice to the
* materials described herein. Cypress does not assume any liability arising out
* of the application or use of any product or circuit described herein. Cypress
* does not authorize its products for use as critical components in life-support
* systems where a malfunction or failure may reasonably be expected to result in
* significant injury to the user. The inclusion of Cypress' product in a life-
* support systems application implies that the manufacturer assumes all risk of
* such use and in doing so indemnifies Cypress against all charges. Use may be
* limited by and subject to the applicable Cypress software license agreement.
*****************************************************************************/
#include <device.h>
#include <stdio.h>

/*AMUX selections*/
#define Select_Single 0 
#define Select_Reference 1

/*IIR Filter parameters*/
#define IIR_FILTER_STEP 16
#define IIR_SHIFT 4

#define dacAddr 0x62
int8 status = 0;
//int32 filt;
//int32 k;

int32 LowPassFilter(int32);

 /*variables for project*/
 int32 iVout1, iVout2, iVcds, iVcds_curr, iVcds_acc, filt, k;
 //float fVcds;

int main(void)
{
   float fVcds;
   char caVcds_decimal_str[15];	//This is for display and collecting data.
   uint8 iLoop;

   /*Initialization*/
   CYGlobalIntEnable;
   ADC_DelSig_1_Start();
   AMux_1_Start();
   Opamp_1_Start();
   //I2C_Start();
   LCD_Start();
   UART_1_Start();
   
   
   /*Display*/
   LCD_Position(0,0);
   LCD_PrintString("Differential");
   /*UART*/
   UART_1_PutChar('\r');
   UART_1_PutChar('\n');
   UART_1_PutString("Differential");
   
	while(1)
    {
		iVcds_acc = 0;
		for(iLoop =0; iLoop < IIR_FILTER_STEP; iLoop++)
    		{
        		/*Get the first sample Vout1*/
        		AMux_1_Select(0);
        		ADC_DelSig_1_StartConvert();
        		ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_WAIT_FOR_RESULT);
        		iVout1 = ADC_DelSig_1_GetResult32();  
        		ADC_DelSig_1_StopConvert();
        		
        		/*Get the second sample Vout2*/
        		AMux_1_Select(1);
        		ADC_DelSig_1_StartConvert();
        		ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_WAIT_FOR_RESULT);
        		iVout2 = ADC_DelSig_1_GetResult32();
        		ADC_DelSig_1_StopConvert();
        		
        		/*perform CDS*/
        		iVcds = iVout1 - iVout2; 
        		
        		/* IIR Filter*/
        		iVcds_curr = iVcds;
        		iVcds_acc = (((iVcds_curr + iVcds_acc) >> IIR_SHIFT));
    		}
	
	/*Display output in desired format on UART*/
//	fVcds = ADC_DelSig_1_CountsTo_Volts(iVout1);
//	UART_1_PutChar('\r');
//	UART_1_PutChar('\n');
//	sprintf(caVcds_decimal_str,"%f",(float)fVcds);
//	UART_1_PutString((uint8*)caVcds_decimal_str);
            
    /*Converted above to print to LCD Display*/
    fVcds = ADC_DelSig_1_CountsTo_uVolts(iVout1);  
    fVcds = (fVcds / 1000000) * 31.921813;
    sprintf(caVcds_decimal_str,"%.5f Volts", fVcds);
    LCD_Position(1,0);
    LCD_PrintString(caVcds_decimal_str);
    }
}

/* [] END OF FILE */
